==> lapisworks-1.5.6.6-sources.jar: com/luxof/lapisworks/items/PartiallyAmelStaff.java <==
package com.luxof.lapisworks.items;

import at.petrak.hexcasting.common.items.ItemStaff;
import at.petrak.hexcasting.common.lib.HexAttributes;

import com.google.common.collect.HashMultimap;
import com.google.common.collect.Multimap;
import com.luxof.lapisworks.items.shit.PartiallyAmelInterface;

import java.util.UUID;

import net.fabricmc.fabric.api.item.v1.FabricItemSettings;
import net.minecraft.class_1268;
import net.minecraft.class_1304;
import net.minecraft.class_1309;
import net.minecraft.class_1320;
import net.minecraft.class_1322;
import net.minecraft.class_1657;
import net.minecraft.class_1799;
import net.minecraft.class_1937;

public class PartiallyAmelStaff extends ItemStaff implements PartiallyAmelInterface {
    private static FabricItemSettings static_settings = new FabricItemSettings().method_7889(1).method_7895(200);

    public class_1322 GRID_ZOOM = new class_1322(
        // same UUID as hextended to not stack on them
        UUID.fromString("a370ec84-ea18-4de6-8730-4271516dcf9c"),
        "Partially Amel Staff Zoom",
        0.35,
        class_1322.class_1323.field_6330
    );
    public class_1322 _getGridZoom() { return this.GRID_ZOOM; }

    public PartiallyAmelStaff() { super(static_settings); }
    public PartiallyAmelStaff(FabricItemSettings props) { super(props); }

    @Override
    public Multimap<class_1320, class_1322> method_7844(class_1304 slot) {
        HashMultimap<class_1320, class_1322> out = HashMultimap.create(super.method_7844(slot));
        if (slot == class_1304.field_6173 || slot == class_1304.field_6171) {
            out.put(HexAttributes.GRID_ZOOM, this._getGridZoom());
        }
        return out;
    }

    @Override
    public void specialUseBehaviour(class_1657 player, class_1937 world, class_1268 hand) {
        class_1799 staff = player.method_5998(hand);
        staff.method_7956(1, player, (class_1309 entity) -> {});
    }

    @Override
    public boolean method_7846() { return true; }
    @Override
    public int getMaxDurability() { return 200; }
    @Override
    public int getAmelWorthInDurability() { return 20; }
}

==> lapisworks-1.5.6.7-sources.jar: com/luxof/lapisworks/items/PartiallyAmelStaff.java <==
package com.luxof.lapisworks.items;

import at.petrak.hexcasting.common.items.ItemStaff;
import at.petrak.hexcasting.common.lib.HexAttributes;

import com.google.common.collect.HashMultimap;
import com.google.common.collect.Multimap;

import com.luxof.lapisworks.items.shit.DurabilityPartAmel;

import java.util.UUID;

import net.fabricmc.fabric.api.item.v1.FabricItemSettings;
import net.minecraft.class_1304;
import net.minecraft.class_1320;
import net.minecraft.class_1322;

public class PartiallyAmelStaff extends ItemStaff implements DurabilityPartAmel {
    private static FabricItemSettings static_settings = new FabricItemSettings().method_7889(1).method_7895(200);

    public class_1322 GRID_ZOOM = new class_1322(
        // same UUID as hextended to not stack on them
        UUID.fromString("a370ec84-ea18-4de6-8730-4271516dcf9c"),
        "Partially Amel Staff Zoom",
        0.35,
        class_1322.class_1323.field_6330
    );
    public class_1322 _getGridZoom() { return this.GRID_ZOOM; }

    public PartiallyAmelStaff() { super(static_settings); }
    public PartiallyAmelStaff(FabricItemSettings props) { super(props); }

    @Override
    public Multimap<class_1320, class_1322> method_7844(class_1304 slot) {
        HashMultimap<class_1320, class_1322> out = HashMultimap.create(super.method_7844(slot));
        if (slot == class_1304.field_6173 || slot == class_1304.field_6171) {
            out.put(HexAttributes.GRID_ZOOM, this._getGridZoom());
        }
        return out;
    }

    @Override
    public int getAmelWorthInDurability() { return 20; }
}
